.. _example_index:

These are examples of the usage of pySAML2!
===========================================

:Release: |version|
:Date: |today|

Contents:

.. toctree::
   :maxdepth: 1

   sp
   idp
   
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

